.onLoad <- function(lib, pkg) {
#library.dynam("robCompositions",pkg,lib)

#	cat("\n ----------------------------------------------\n")	
#    print(citation("robCompositions"))
#
#	cat("\n ----------- FOR IMPUTATION  ------------------\n")	
#	print(citEntry(entry="Article",
#              title = "Imputation of missing values for compositional data using classical and robust methods",
#              author = personList(as.person("Karel Hron"),
 #                                 as.person("Matthias Templ"),
#                                  as.person("Peter Filzmoser")),
#			  journal = "Computational Statistics and Data Analysis",#
#			  volume = "54",
#			  pages = "",
 #             year = "2010",
#              textVersion = 
#               paste("Karel Hron, Matthias Templ, Peter Filzmoser",
#                    " (2010). robCompositions: Robust Compositional Methods ", ".", sep=""))    )
#cat("\n--------\n\n")   
#cat("for references have a look at\n")
#cat("citation('robCompositions')    \n")                 
#cat("--------\n\n")  

}

.onUnload <- function(libpath)
   library.dynam.unload("robCompositions",  libpath)

robGUIenvir <- new.env()